# Kaiban Python SDK

Python implementation of the Kaiban SDK.

## Installation

```bash
pip install kaiban
```


```python
from kaiban import hello
hello.world() # Outputs: Hello from Kaiban!
```

## Development
1. Clone the repository
2. Navigate to the Python SDK directory: `cd python`
3. Install development dependencies: `pip install -e ".[dev]"`
4. Run tests: `pytest`